﻿using System;
using NUnit.Framework;
using OpenQA.Selenium;
using OpenQA.Selenium.Firefox;
using OpenQA.Selenium.Support.UI;

namespace WaitExample
{
    [TestFixture]
    public class SeleniumWait
    {
        private IWebDriver _driver;

        [SetUp]
        public void Setup()
        {
            _driver = new FirefoxDriver();
        }

        [Test]
        public void Search_ShouldReturn_CorrectRestaurantName()
        {
            _driver.Navigate().GoToUrl("http://www.bookatable.com/");

            // Find the search box and type some text
            IWebElement searchBox = _driver.FindElement(By.Name("ddRestaurants"));

            searchBox.Click();

            searchBox.SendKeys("or");

            // Test the autocomplete response
            IWebElement autocomplete = _driver.FindElement(By.ClassName("ac-row-110457"));

            string autoCompleteResults = autocomplete.Text;

            Assert.That(autoCompleteResults, Is.EqualTo("A la cloche d'Or\r\nParis, France"));
        }

        [Test]
        public void Search_ShouldReturn_CorrectRestaurantName_WithExplicitWait()
        {
            _driver.Navigate().GoToUrl("http://www.bookatable.com/");

            // Find the search box and type some text
            IWebElement searchBox = _driver.FindElement(By.Name("ddRestaurants"));

            searchBox.Click();

            searchBox.SendKeys("or");

            // TODO: You need to add a reference to Webdriver.Support.dll
            // Tell webdriver to wait
            WebDriverWait wait = new WebDriverWait(_driver, TimeSpan.FromSeconds(4));

            // Test the autocomplete response
            IWebElement autocomplete = wait.Until(x => x.FindElement(By.ClassName("ac-row-110457")));

            string autoCompleteResults = autocomplete.Text;

            Assert.That(autoCompleteResults, Is.EqualTo("A la cloche d'Or\r\nParis, France"));
        }

        [Test]
        public void Search_ShouldReturn_CorrectRestaurantName_WithImplicitWait()
        {
            _driver.Navigate().GoToUrl("http://www.bookatable.com/");

            // Find the search box and type some text
            IWebElement searchBox = _driver.FindElement(By.Name("ddRestaurants"));

            searchBox.Click();

            searchBox.SendKeys("or");

            // Tell autocomplete to wait
            _driver.Manage().Timeouts().ImplicitlyWait(TimeSpan.FromSeconds(4));

            // Test the autocomplete response
            IWebElement autocomplete = _driver.FindElement(By.ClassName("ac-row-110457"));

            string autoCompleteResults = autocomplete.Text;

            Assert.That(autoCompleteResults, Is.EqualTo("A la cloche d'Or\r\nParis, France"));
        }

        [TearDown]
        public void TearDown()
        {
            _driver.Close();
        }
    }
}
